<?php
namespace src\Blog\Admin\Controller;
use Plugin\Controller\Container;
use Plugin\Exception\Error;
class DashController extends Container {
	
	public function __construct(){
		$userAuth = $this->get("authentication");
		
		if (!$userAuth->isAuthorized()){
			// send to log in page;
			//$userAuth->gotoLogin();
		}
		
		$this->setSlots("active-nav", "dash");
	}
	
	public function dashboardAction(){
		$this->setSlots("title", "Welcome to the Admin");
		$render = "Blog:Admin:Home/dashboard.html.php";
		$vars = array();
		return $this->render("Blog:Admin:index.html.php",array("render"=>$render,"content"=>$vars));
		
	}
	
	public function listArticleAction(){
		$this->setSlots("active-nav", "art-list");
		$this->setSlots("title", "Welcome to the Admin");
		$render = "Blog:Admin:Home/artlist.html.php";
		$vars = array();
		$em = $this->getManager();
		
		$vars["articles"] = $em->get("Blog:Model:Article")->getAllArticlesList();
		return $this->render("Blog:Admin:index.html.php",array("render"=>$render,"content"=>$vars));
		
	}
	
	public function editPostAction($id){
		$em = $this->getManager();
		$this->setSlots("active-nav", "art-list");
		$article = $em->get("Blog:Model:Article")->getById($id);
		if (!$article){
			Error::throw404("This Article does not exist");
		}
		
		$req = $this->getRequest();
		if ($req->getMethod() === "POST"){
			$status = $em->get("Blog:Model:Article")->saveEdit($id,$req);
			$url = $req->generateUrl("AdminEditArticle",array("id"=>$id,"status"=>$status));
			$req->redirectToUrl($url);
			// this will exit
		}
		
		$this->setSlots("title", "Editing: ".htmlentities($article->title));
		$render = "Blog:Admin:Home/editpost.html.php";
		$vars = array();
		$vars["status"] = $req->getParam("status");
		
		$vars["article"] = $article;
		return $this->render("Blog:Admin:index.html.php",array("render"=>$render,"content"=>$vars));
		
	}
	
	public function addNewAction(){
		$this->setSlots("active-nav", "add-new");
		$this->setSlots("title", "Add A new Article");
		$req = $this->getRequest();
		
		if ($req->getMethod() === "POST") {
			$em = $this->getManager();
			$id = $em->get("Blog:Model:Article")->saveArticle($req);
			if (!$id){
				// error: fill the form with previous data and display error
			}else {
				$url = $req->generateUrl("AdminEditArticle",array("id"=>$id));
				$req->redirectToUrl($url);
			}
			// and we are done
		}
		
		$render = "Blog:Admin:Home/addpost.html.php";
		$vars = array();
		
		return $this->render("Blog:Admin:index.html.php",array("render"=>$render,"content"=>$vars));
	}
}

